==> flyspray_0.9.6a.orig.tar.gz: flyspray-0.9.6/lang/de/details.php <==
﻿<?php

global $details_text;
$details_text = array (

'task'              =>  'Aufgabe',
'edittask'          =>  'Aufgabe bearbeiten',
'openedby'          =>  'Geöffnet von',
'editedby'          =>  'Zuletzt bearbeitet von',
'tasktype'          =>  'Aufgabentyp',
'category'          =>  'Kategorie',
'status'            =>  'Status',
'assignedto'        =>  'Zugeteilt',
'noone'             =>  'Niemand',
'operatingsystem'   =>  'Betriebssystem',
'severity'          =>  'Schweregrad',
'reportedversion'   =>  'Berichtete Version',
'dueinversion'      =>  'Fällig in Version',
'undecided'         =>  'Unentschieden',
'percentcomplete'   =>  'Prozent erledigt',
'details'           =>  'Details',
'savedetails'       =>  'Details speichern',
'canceledit'        =>  'Bearbeiten abbrechen',
'anonymous'         =>  'Anonymer Reporter',
'complete'          =>  'erledigt',
'closedby'          =>  'Geschlossen von',
'reasonforclosing'  =>  'Grund für das Schließen:',
'reopenthistask'    =>  'Aufgabe wieder öffnen',
'closetask'         =>  'Aufgabe schließen',
'comments'          =>  'Kommentare',
'attachments'       =>  'Anhänge',
'relatedtasks'      =>  'Verwandte Aufgaben',
'notifications'     =>  'Benachrichtigungen',
'edit'              =>  'Bearbeiten',
'delete'            =>  'Löschen',
'commentby'         =>  'Kommentar von',
'addcomment'        =>  'Kommentar hinzufügen',
'fileuploadedby'    =>  'Date hochgeladen von',
'uploadafile'       =>  'Datei zum Anhängen hochladen',
'description'       =>  'Beschreibung',
'uploadnow'         =>  'Hochladen!',
'thesearerelated'   =>  'Folgende Aufgaben sind mit dieser verwandt',
'remove'            =>  'Entfernen',
'addnewrelated'     =>  'Verwandte Aufgabe hinzufügen',
'add'               =>  'Hinzufügen!',
'otherrelated'      =>  'Andere Aufgaben, mit denen diese verwandt ist',
'receivenotify'     =>  'Diese Benutzer werden detaillierte Benachrichtigungen erhalten, wenn sich diese Aufgabe ändert.',
'addusertolist'     =>  'Benutzer zu dieser Liste hinzufügen',
'addtolist'         =>  'Zu Liste hinzufügen',
'addmyself'         =>  'Mich selbst zu dieser Liste hinzufügen',
'removemyself'      =>  'Mich selbst von dieser Liste entfernen',
'invalidtaskid'     =>  'Es gibt keine Aufgabe mit dieser ID!',
'theseusersnotify'  =>  'Folgende Benutzer erhalten detaillierte Benachrichtigungen, sobald sich die Aufgabe ändert',

// Added in version 0.9.5

'attachedtoproject'	=>	'gehört zu Projekt',

// Added in version 0.9.6

'reminders'         =>   'Erinnerungen',
'remindthisuser'    =>   'Diesen Benutzer',
'thisoften'         =>   'so oft erinnern',
'startafter'        =>   'Zeit bis zur ersten Erinnerung',
'hours'             =>   'Stunde(n)',
'days'              =>   'Tag(e)',
'weeks'             =>   'Woche(n)',
'addreminder'       =>   'Erinnerung hinzufügen',
'defaultreminder'   =>   'Dies ist eine Erinnerung, einen Blick auf die folgende Flyspray-Aufgabe zu werfen:',
'message'           =>   'Nachricht',
'closed'			=>   'Geschlossen',
'filename'			=>   'Dateiname:',
'date'				=>   'Datum:',
'filesize'			=>   'Dateigröße:',
'closurecomment'	=>   'Zusätzlicher Kommentar zur Schließung:',

'history'           =>   'Historie',
'nohistory'         =>   'Keine Daten verfügbar.',
'eventdate'         =>   'Datum',
'user'              =>   'Benutzer',
'event'             =>   'Ereignis',
'fieldchanged'      =>   'Feld geändert',
'taskopened'        =>   'Aufgabe geöffnet',
'taskreopened'      =>   'Aufgabe wiedereröffnet',
'taskclosed'        =>   'Aufgabe geschlossen',
'commentadded'      =>   'Kommentar hinzugefügt',
'commentedited'     =>   'Kommentar geändert',
'commentdeleted'    =>   'Kommentar gelöscht',
'attachmentadded'   =>   'Anhang hinzugefügt',
'attachmentdeleted' =>   'Anhang gelöscht',
'taskedited'        =>   'Aufgabendetails geändert',
'notificationadded' =>   'Benutzer zur Benachrichtigungsliste hinzugefügt',
'notificationdeleted' => 'Benutzer von der Benachrichtigungsliste entfernt',
'relatedadded'      =>   'Verwandte Aufgabe hinzugefügt',
'relateddeleted'    =>   'Verwandte Aufgabe entfernt',
'taskassigned'      =>   'Aufgabe zugeteilt an',
'taskreassigned'    =>   'Aufgabe neu zugeteilt an',
'assignmentremoved' =>   'Zuteilung rückgängig gemacht',
'summary'           =>   'Zusammenfassung',
'addedasrelated'    =>   'Aufgabe hinzugefügt zur Verwandtschaftsliste von Aufgabe',
'deletedasrelated'  =>   'Aufgabe entfernt von der Verwandtschaftsliste von Aufgabe',
'reminderadded'     =>   'Erinnerung hinzugefügt',
'reminderdeleted'   =>   'Erinnerung entfernt',
'priority'          =>   'Priorität',
'previousvalue'     =>   'Voriger Wert',
'newvalue'          =>   'Neuer Wert',

);
?>

==> flyspray_0.9.7.orig.tar.gz: flyspray-0.9.7/lang/de/details.php <==
<?php

global $details_text;
$details_text = array (

'task'              =>  'Aufgabe',
'edittask'          =>  'Aufgabe bearbeiten',
'openedby'          =>  'Geöffnet von',
'editedby'          =>  'Zuletzt bearbeitet von',
'tasktype'          =>  'Aufgabentyp',
'category'          =>  'Kategorie',
'status'            =>  'Status',
'assignedto'        =>  'Zugeteilt',
'noone'             =>  'Niemand',
'operatingsystem'   =>  'Betriebssystem',
'severity'          =>  'Schweregrad',
'reportedversion'   =>  'Berichtete Version',
'dueinversion'      =>  'Fällig in Version',
'undecided'         =>  'Unentschieden',
'percentcomplete'   =>  'Prozent erledigt',
'details'           =>  'Details',
'savedetails'       =>  'Details speichern',
'canceledit'        =>  'Bearbeiten abbrechen',
'anonymous'         =>  'Anonymer Reporter',
'complete'          =>  'erledigt',
'closedby'          =>  'Geschlossen von',
'reasonforclosing'  =>  'Grund für das Schließen:',
'reopenthistask'    =>  'Aufgabe wieder öffnen',
'closetask'         =>  'Aufgabe schließen',
'comments'          =>  'Kommentare',
'attachments'       =>  'Anhänge',
'relatedtasks'      =>  'Verwandte Aufgaben',
'notifications'     =>  'Benachrichtigungen',
'edit'              =>  'Bearbeiten',
'delete'            =>  'Löschen',
'commentby'         =>  'Kommentar von',
'addcomment'        =>  'Kommentar hinzufügen',
'fileuploadedby'    =>  'Date hochgeladen von',
'uploadafile'       =>  'Datei zum Anhängen hochladen',
'description'       =>  'Beschreibung',
'uploadnow'         =>  'Hochladen!',
'thesearerelated'   =>  'Folgende Aufgaben sind mit dieser verwandt',
'remove'            =>  'Entfernen',
'addnewrelated'     =>  'Verwandte Aufgabe hinzufügen',
'add'               =>  'Hinzufügen!',
'otherrelated'      =>  'Andere Aufgaben, mit denen diese verwandt ist',
'receivenotify'     =>  'Diese Benutzer werden detaillierte Benachrichtigungen erhalten, wenn sich diese Aufgabe ändert.',
'addusertolist'     =>  'Benutzer zu dieser Liste hinzufügen',
'addtolist'         =>  'Zu Liste hinzufügen',
'addmyself'         =>  'Mich selbst zu dieser Liste hinzufügen',
'removemyself'      =>  'Mich selbst von dieser Liste entfernen',
'invalidtaskid'     =>  'Es gibt keine Aufgabe mit dieser ID!',
'theseusersnotify'  =>  'Folgende Benutzer erhalten detaillierte Benachrichtigungen, sobald sich die Aufgabe ändert',

// Added in version 0.9.5

'attachedtoproject'	=>	'gehört zu Projekt',

// Added in version 0.9.6

'reminders'         =>   'Erinnerungen',
'remindthisuser'    =>   'Diesen Benutzer',
'thisoften'         =>   'so oft erinnern',
'startafter'        =>   'Zeit bis zur ersten Erinnerung',
'hours'             =>   'Stunde(n)',
'days'              =>   'Tag(e)',
'weeks'             =>   'Woche(n)',
'addreminder'       =>   'Erinnerung hinzufügen',
'defaultreminder'   =>   'Dies ist eine Erinnerung, einen Blick auf die folgende Flyspray-Aufgabe zu werfen:',
'message'           =>   'Nachricht',
'closed'			=>   'Geschlossen',
'filename'			=>   'Dateiname:',
'date'				=>   'Datum:',
'filesize'			=>   'Dateigröße:',
'closurecomment'	=>   'Zusätzlicher Kommentar zur Schließung:',

'history'           =>   'Historie',
'nohistory'         =>   'Keine Daten verfügbar.',
'eventdate'         =>   'Datum',
'user'              =>   'Benutzer',
'event'             =>   'Ereignis',
'fieldchanged'      =>   'Feld geändert',
'taskopened'        =>   'Aufgabe geöffnet',
'taskreopened'      =>   'Aufgabe wiedereröffnet',
'taskclosed'        =>   'Aufgabe geschlossen',
'commentadded'      =>   'Kommentar hinzugefügt',
'commentedited'     =>   'Kommentar geändert',
'commentdeleted'    =>   'Kommentar gelöscht',
'attachmentadded'   =>   'Anhang hinzugefügt',
'attachmentdeleted' =>   'Anhang gelöscht',
'taskedited'        =>   'Aufgabendetails geändert',
'notificationadded' =>   'Benutzer zur Benachrichtigungsliste hinzugefügt',
'notificationdeleted' => 'Benutzer von der Benachrichtigungsliste entfernt',
'relatedadded'      =>   'Verwandte Aufgabe hinzugefügt',
'relateddeleted'    =>   'Verwandte Aufgabe entfernt',
'taskassigned'      =>   'Aufgabe zugeteilt an',
'taskreassigned'    =>   'Aufgabe neu zugeteilt an',
'assignmentremoved' =>   'Zuteilung rückgängig gemacht',
'summary'           =>   'Zusammenfassung',
'addedasrelated'    =>   'Aufgabe hinzugefügt zur Verwandtschaftsliste von Aufgabe',
'deletedasrelated'  =>   'Aufgabe entfernt von der Verwandtschaftsliste von Aufgabe',
'reminderadded'     =>   'Erinnerung hinzugefügt',
'reminderdeleted'   =>   'Erinnerung entfernt',
'priority'          =>   'Priorität',
'previousvalue'     =>   'Voriger Wert',
'newvalue'          =>   'Neuer Wert',

// Added in version 0.9.7
'selectareason'     =>  'Wählen Sie eine Begründung',
'assigntome'        =>  'Mir zuteilen',
'reopenrequest'     =>  'Wiedereröffnung anfordern',
'requestclose'      =>  'Schließung anfordern',
'ownershiptaken'    =>  'Benutzer hat sich die Aufgabe zugeteilt',
'closerequestmade'  =>  'Schließung einer Aufgabe angefordert',
'reopenrequestmade' =>  'Wiedereröffnung einer Aufgabe angefordert',
'taskdependson'     =>  'Diese Aufgabe hängt ab von',
'taskblocks'        =>  'Diese Aufgabe verhindert die Schließung von',
'addnew'            =>  'Neue hinzufügen',
'depadded'          =>  'Abhängigkeit hinzugefügt:',
'depaddedother'     =>  'Diese Aufgabe als Abhängigkeit hinzugefügt:',
'depremoved'        =>  'Abhängigkeit entfernt:',
'depremovedother'   =>  'Entfernt von der Abhängigkeitsliste von:',
'showdetailserror'  =>  'Diese Aufgabe existiert nicht oder Sie haben keine Berechtigung, sie anzuzeigen.',
'makeprivate'       =>  'Verstecken',
'makepublic'        =>  'Öffentlich machen',
'taskmadeprivate'   =>  'Aufgabe versteckt',
'taskmadepublic'    =>  'Aufgabe öffentlich gemacht',
);
?>
